Learn R Programming

bayes4psy (version 1.2.13)

compare_distributions,success_rate_class-method: compare_distributions

Description

compare_distributions draws samples from distribution of the first group and compares them against samples drawn from the distribution of the second group or from samples drawn from distributions of multiple groups.

Usage

# S4 method for success_rate_class
compare_distributions(object, ...)

Value

Comparison results or an error if something went wrong.

Arguments

object

success_rate_class object.

...

fit2 - a second success_rate_class object, fits - a list of success_rate_class objects, rope - region of practical equivalence.

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?success_rate_class

Run the code above in your browser using DataLab