Learn R Programming

bayes4psy (version 1.2.13)

compare_distributions,ttest_class-method: compare_distributions

Description

compare_distributions draws samples from distribution of the first group and compares them against samples drawn from the distribution of the second group, against samples drawn from distributions of multiple groups, against a mean value or against samples from a normal distribution with a defined mean value and variance.

Usage

# S4 method for ttest_class
compare_distributions(object, ...)

Value

Comparison results or an error if something went wrong.

Arguments

object

ttest_class object.

...

fit2 - a second ttest_class object, fits - a list of ttest_class objects, mu - mean value, sigma - standard deviation, rope - region of practical equivalence.

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?ttest_class

Run the code above in your browser using DataLab