Learn R Programming

bayes4psy (version 1.2.13)

compare_means,color_class-method: compare_means

Description

compare_means prints difference in colors between two fits or a fit and a color.

Usage

# S4 method for color_class
compare_means(object, ...)

Value

Comparison results or an error if something went wrong.

Arguments

object

color_class object.

...

fit2 - a second color_class object, rgb - color defined through rgb, hsv - color defined through rgb, rope - region of practical equivalence, pars - components of comparison, a subset of (r, g, b, h, s, v).

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?color_class

Run the code above in your browser using DataLab