Learn R Programming

bayes4psy (version 1.2.13)

compare_means,reaction_time_class-method: compare_means

Description

compare_means prints difference in reaction times between two groups or multiple groups.

Usage

# S4 method for reaction_time_class
compare_means(object, ...)

Value

Comparison results or an error if something went wrong.

Arguments

object

reaction_time_class object.

...

fit2 - a second reaction_time_class object, fits - a list of reaction_time_class objects, rope - region of practical equivalence, par - specific parameter of comparison (mu or lambda).

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?reaction_time_class

Run the code above in your browser using DataLab