Learn R Programming

bayes4psy (version 1.2.13)

compare_means,ttest_class-method: compare_means

Description

compare_means prints difference/equality of the first group against the second group, against multiple groups, against a mean value or against a normal distribution with a defined mean value and variance.

Usage

# S4 method for ttest_class
compare_means(object, ...)

Value

Comparison results or an error if something went wrong.

Arguments

object

ttest_class object.

...

fit2 - a second ttest_class object, mu - mean value, sigma - standard deviation, fits - a list of ttest_class objects, rope - region of practical equivalence, par - execute comparison through the sigma or nu parameter.

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?ttest_class

Run the code above in your browser using DataLab