Learn R Programming

bayes4psy (version 1.2.13)

show,ttest_class-method: show

Description

show prints a more detailed summary of the Bayesian ttest fit.

Usage

# S4 method for ttest_class
show(object)

Arguments

object

ttest_class object.

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?ttest_class

Run the code above in your browser using DataLab