Learn R Programming

bayes4psy (version 1.2.13)

show,success_rate_class-method: show

Description

show prints a more detailed summary of the Bayesian success rate fit.

Usage

# S4 method for success_rate_class
show(object)

Arguments

object

success_rate_class object.

Examples

Run this code
# to use the function you first have to prepare the data and fit the model
# see class documentation for an example of the whole process
# along with an example of how to use this function
?success_rate_class

Run the code above in your browser using DataLab