A user-friendly implementation of Bayesian statistical methods commonly used in social sciences. All used models are pre-compiled, meaning that users only need to call appropriate functions using their data.
Arguments
References
Stan Development Team (NA) - the Stan framework and RStan interface.
John Kruschke - mcmc_hdi function
Rasmus Bååth - Easy Bayesian Bootstrap in R